==> adx-nezha-engine-api-1.0.08-sources.jar: cn/com/duiba/nezha/engine/api/enums/ModelKeyEnum.java <==
package cn.com.duiba.nezha.engine.api.enums;

public enum ModelKeyEnum {

    // FFM_CTR
    FFM_CTR_MODEL_V001("mid_ftrl_ffm_ctr_v001", ModelType.FFM, true),
    FFM_CTR_MODEL_V002("mid_ftrl_ffm_ctr_v002", ModelType.FFM, true),
    FFM_CTR_MODEL_V004("mid_ftrl_ffm_ctr_v004", ModelType.FFM, true),

    //FFM_CVR
    FFM_BCVR_MODEL_V001("mid_ftrl_ffm_bcvr_v001", ModelType.FFM, true),
    FFM_BCVR_MODEL_V002("mid_ftrl_ffm_bcvr_v002", ModelType.FFM, true),
    FFM_BCVR_MODEL_V004("mid_ftrl_ffm_bcvr_v004", ModelType.FFM, true),

    //FM_CTR
    FM_CTR_MODEL_v003("mid_fm_ctr_v003", ModelType.FM, false),
    FM_CTR_MODEL_v603("mid_fm_ctr_v603", ModelType.FM, false),

    //FM_CVR
    FM_BCVR_MODEL_v003("mid_fm_bcvr_v003", ModelType.FM, false),
    FM_BCVR_MODEL_v603("mid_fm_be_cvr_v603", ModelType.FM, false),

    //FM_CTR
    FTRL_FM_CTR_MODEL_v002("mid_ftrl_fm_ctr_v002", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v004("mid_ftrl_fm_ctr_v004", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v007("mid_ftrl_fm_ctr_v007", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v009("mid_ftrl_fm_ctr_v009", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v010("mid_ftrl_fm_ctr_v010", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v011("mid_ftrl_fm_ctr_v011", ModelType.FM, true),


    FTRL_FM_CTR_MODEL_v701("mid_ftrl_fm_ctr_v701", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v702("mid_ftrl_fm_ctr_v702", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v703("mid_ftrl_fm_ctr_v703", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v704("mid_ftrl_fm_ctr_v704", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v711("mid_ftrl_fm_ctr_v711", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v712("mid_ftrl_fm_ctr_v712", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v713("mid_ftrl_fm_ctr_v713", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v714("mid_ftrl_fm_ctr_v714", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v715("mid_ftrl_fm_ctr_v715", ModelType.FM, true),


    //FM_CVR
    FTRL_FM_BCVR_MODEL_v002("mid_ftrl_fm_bcvr_v002", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v004("mid_ftrl_fm_bcvr_v004", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v007("mid_ftrl_fm_bcvr_v007", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v009("mid_ftrl_fm_bcvr_v009", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v010("mid_ftrl_fm_bcvr_v010", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v011("mid_ftrl_fm_bcvr_v011", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v012("mid_ftrl_fm_bcvr_v012", ModelType.FM, true),

    FTRL_FM_BCVR_MODEL_v701("mid_ftrl_fm_bcvr_v701", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v702("mid_ftrl_fm_bcvr_v702", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v703("mid_ftrl_fm_bcvr_v703", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v704("mid_ftrl_fm_bcvr_v704", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v711("mid_ftrl_fm_bcvr_v711", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v712("mid_ftrl_fm_bcvr_v712", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v713("mid_ftrl_fm_bcvr_v713", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v714("mid_ftrl_fm_bcvr_v714", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v715("mid_ftrl_fm_bcvr_v715", ModelType.FM, true),


    FTRL_FM_CVR_MODEL_v611("mid_ftrl_fm_cvr_v611", ModelType.FM, true),
    FTRL_FM_CVR_MODEL_v612("mid_ftrl_fm_cvr_v612", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v611("mid_ftrl_fm_ctr_v611", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v612("mid_ftrl_fm_ctr_v612", ModelType.FM, true),

    //FM_CODER
    FTRL_CODER_CTR_V001("mid_ftrl_coder_ctr_v001", ModelType.CODER, true),
    FTRL_CODER_BCVR_V001("mid_ftrl_coder_bcvr_v001", ModelType.CODER, true),

    //增值场景 CTR 模型
    ZZ_FTRL_FM_CTR_MODEL_v001("zz_mid_ftrl_fm_ctr_v001", ModelType.FM, true),
    ZZ_FTRL_FM_CTR_MODEL_v002("zz_mid_ftrl_fm_ctr_v002", ModelType.FM, true),
    //增值场景 CVR 模型
    ZZ_MID_FTRL_FM_BCVR_V001("zz_mid_ftrl_fm_bcvr_v001", ModelType.FM, true),
    ;
    private String index;

    private ModelType modelType;

    private Boolean online;

    public String getIndex() {
        return index;
    }

    public ModelType getModelType() {
        return modelType;
    }

    public Boolean getOnline() {
        return online;
    }

    ModelKeyEnum(String index, ModelType modelType, Boolean online) {
        this.index = index;
        this.modelType = modelType;
        this.online = online;
    }
}

==> adx-nezha-engine-api-1.0.18-sources.jar: cn/com/duiba/nezha/engine/api/enums/ModelKeyEnum.java <==
package cn.com.duiba.nezha.engine.api.enums;

public enum ModelKeyEnum {

    // FFM_CTR
    FFM_CTR_MODEL_V001("mid_ftrl_ffm_ctr_v001", ModelType.FFM, true),
    FFM_CTR_MODEL_V002("mid_ftrl_ffm_ctr_v002", ModelType.FFM, true),
    FFM_CTR_MODEL_V004("mid_ftrl_ffm_ctr_v004", ModelType.FFM, true),

    //FFM_CVR
    FFM_BCVR_MODEL_V001("mid_ftrl_ffm_bcvr_v001", ModelType.FFM, true),
    FFM_BCVR_MODEL_V002("mid_ftrl_ffm_bcvr_v002", ModelType.FFM, true),
    FFM_BCVR_MODEL_V004("mid_ftrl_ffm_bcvr_v004", ModelType.FFM, true),

    //FM_CTR
    FM_CTR_MODEL_v003("mid_fm_ctr_v003", ModelType.FM, false),
    FM_CTR_MODEL_v603("mid_fm_ctr_v603", ModelType.FM, false),

    //FM_CVR
    FM_BCVR_MODEL_v003("mid_fm_bcvr_v003", ModelType.FM, false),
    FM_BCVR_MODEL_v603("mid_fm_be_cvr_v603", ModelType.FM, false),

    //FM_CTR
    FTRL_FM_CTR_MODEL_v002("mid_ftrl_fm_ctr_v002", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v004("mid_ftrl_fm_ctr_v004", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v007("mid_ftrl_fm_ctr_v007", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v009("mid_ftrl_fm_ctr_v009", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v010("mid_ftrl_fm_ctr_v010", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v011("mid_ftrl_fm_ctr_v011", ModelType.FM, true),


    FTRL_FM_CTR_MODEL_v701("mid_ftrl_fm_ctr_v701", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v702("mid_ftrl_fm_ctr_v702", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v703("mid_ftrl_fm_ctr_v703", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v704("mid_ftrl_fm_ctr_v704", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v711("mid_ftrl_fm_ctr_v711", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v712("mid_ftrl_fm_ctr_v712", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v713("mid_ftrl_fm_ctr_v713", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v714("mid_ftrl_fm_ctr_v714", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v715("mid_ftrl_fm_ctr_v715", ModelType.FM, true),


    //FM_CVR
    FTRL_FM_BCVR_MODEL_v002("mid_ftrl_fm_bcvr_v002", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v004("mid_ftrl_fm_bcvr_v004", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v007("mid_ftrl_fm_bcvr_v007", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v009("mid_ftrl_fm_bcvr_v009", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v010("mid_ftrl_fm_bcvr_v010", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v011("mid_ftrl_fm_bcvr_v011", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v012("mid_ftrl_fm_bcvr_v012", ModelType.FM, true),

    FTRL_FM_BCVR_MODEL_v701("mid_ftrl_fm_bcvr_v701", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v702("mid_ftrl_fm_bcvr_v702", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v703("mid_ftrl_fm_bcvr_v703", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v704("mid_ftrl_fm_bcvr_v704", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v711("mid_ftrl_fm_bcvr_v711", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v712("mid_ftrl_fm_bcvr_v712", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v713("mid_ftrl_fm_bcvr_v713", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v714("mid_ftrl_fm_bcvr_v714", ModelType.FM, true),
    FTRL_FM_BCVR_MODEL_v715("mid_ftrl_fm_bcvr_v715", ModelType.FM, true),


    FTRL_FM_CVR_MODEL_v611("mid_ftrl_fm_cvr_v611", ModelType.FM, true),
    FTRL_FM_CVR_MODEL_v612("mid_ftrl_fm_cvr_v612", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v611("mid_ftrl_fm_ctr_v611", ModelType.FM, true),
    FTRL_FM_CTR_MODEL_v612("mid_ftrl_fm_ctr_v612", ModelType.FM, true),

    //FM_CODER
    FTRL_CODER_CTR_V001("mid_ftrl_coder_ctr_v001", ModelType.CODER, true),
    FTRL_CODER_BCVR_V001("mid_ftrl_coder_bcvr_v001", ModelType.CODER, true),

    //增值场景 CTR 模型
    ZZ_FTRL_FM_CTR_MODEL_v001("zz_mid_ftrl_fm_ctr_v001", ModelType.FM, true),
    ZZ_FTRL_FM_CTR_MODEL_v002("zz_mid_ftrl_fm_ctr_v002", ModelType.FM, true),
    //增值场景 CVR 模型
    ZZ_MID_FTRL_FM_BCVR_V001("zz_mid_ftrl_fm_bcvr_v001", ModelType.FM, true),

    // FM_DCVR
    FTRL_FM_DCVR_MODEL_v001("mid_ftrl_fm_dcvr_v001", ModelType.FM, true),
    FTRL_FM_DCVR_MODEL_v004("mid_adam_fm_dcvr_v004", ModelType.FM, true),
    FTRL_FM_DCVR_MODEL_INC_v001("mid_ftrl_fm_dcvr_inc_v001", ModelType.FM, true),
    MID_ADAM_FM_DCVR_V009("mid_adam_fm_dcvr_v009", ModelType.FM, true),

    // fm人群定定向模型
    FTRL_FM_CROWD_ADVERT_V004("ftrl_fm_crowd_advert_v004", ModelType.FM, true),

    FTRL_FM_CROWD_ADVERT_V003("ftrl_fm_crowd_advert_v003", ModelType.FM, true),

    ;
    private String index;

    private ModelType modelType;

    private Boolean online;

    public String getIndex() {
        return index;
    }

    public ModelType getModelType() {
        return modelType;
    }

    public Boolean getOnline() {
        return online;
    }

    ModelKeyEnum(String index, ModelType modelType, Boolean online) {
        this.index = index;
        this.modelType = modelType;
        this.online = online;
    }
}
